@@ -53,13 +53,13 @@
 #include <gedit-file.h>
 #include <dialogs/gedit-dialogs.h>
 
-#define DIFF_BASE_KEY 		"/apps/gedit2/plugins/diff"
+#define DIFF_BASE_KEY 		"/apps/gedit-2/plugins/diff"
 #define DIFF_LOCATION_KEY	"/diff-program-location"
 #define UNIFIED_FORMAT_KEY	"/use-unified-format"
 #define IGNORE_BLANKS		"/ignore-blanks"
 
-#define MENU_ITEM_LABEL		N_("_Compare files...")
-#define MENU_ITEM_PATH		"/menu/File/FileOps/"
+#define MENU_ITEM_LABEL		N_("Co_mpare Files...")
+#define MENU_ITEM_PATH		"/menu/File/FileOps_2/"
 #define MENU_ITEM_NAME		"Diff"	
 #define MENU_ITEM_TIP		N_("Makes a diff file from two documents or files")
 
