@@ -142,6 +142,8 @@ gedit_file_open_real (const gchar* file_name, GeditMDIChild* active_child)
 {
 	GError *error = NULL;
 	gchar* uri;
+	GeditRecent *recent;
+	BonoboWindow *win;
 
 	gedit_debug (DEBUG_FILE, "File name: %s", file_name);
 
@@ -193,8 +195,9 @@ gedit_file_open_real (const gchar* file_name, GeditMDIChild* active_child)
 		}	
 	}
 
-	gedit_recent_add (uri);
-	gedit_recent_update_all_windows (BONOBO_MDI (gedit_mdi)); 
+	win = gedit_get_active_window ();
+	recent = gedit_mdi_get_recent_from_window (win);
+	gedit_recent_add (recent, uri);
 
 	g_free (uri);
 
@@ -264,12 +267,16 @@ gedit_file_save (GeditMDIChild* child)
 	}	
 	else
 	{
+		BonoboWindow *win;
+		GeditRecent *recent;
+
 		gedit_debug (DEBUG_FILE, "OK");
 
 		gedit_utils_flash_va (_("File '%s' saved."), uri);
 
-		gedit_recent_add (uri);
-		gedit_recent_update_all_windows (BONOBO_MDI (gedit_mdi)); 
+		win = gedit_get_active_window ();
+		recent = gedit_mdi_get_recent_from_window (win);
+		gedit_recent_add (recent, uri);
 
 		g_free (uri);
 
@@ -357,10 +364,14 @@ gedit_file_save_as_real (const gchar* file_name, GeditMDIChild *child)
 	}	
 	else
 	{
+		BonoboWindow *win;
+		GeditRecent *recent;
+
 		gedit_debug (DEBUG_FILE, "OK");
 
-		gedit_recent_add (uri);
-		gedit_recent_update_all_windows (BONOBO_MDI (gedit_mdi)); 
+		win = gedit_get_active_window ();
+		recent = gedit_mdi_get_recent_from_window (win);
+		gedit_recent_add (recent, uri);
 
 		g_free (uri);
 
@@ -406,8 +417,6 @@ gedit_file_exit (void)
 	
 	gedit_prefs_save_settings ();
 
-	gedit_recent_history_save ();
-
 	gedit_debug (DEBUG_FILE, "Unref gedit_mdi.");
 
 	g_object_unref (G_OBJECT (gedit_mdi));
@@ -569,28 +578,18 @@ gedit_file_open_uri_list (GList* uri_list, gint line)
 }
 
 gboolean 
-gedit_file_open_recent (GeditMDIChild *child, const gchar* uri)
+gedit_file_open_recent (GeditRecent *recent, const gchar *uri, gpointer data)
 {
 	gboolean ret;
-	gchar *temp_uri;
+	GeditView* active_view;
 
 	gedit_debug (DEBUG_FILE, "Open : %s", uri);
 
-	/* we need to do this to avoid gedit_recent_add() freeing our uri */
-	temp_uri = g_strdup (uri);
-	
-	ret = gedit_file_open_real (temp_uri, child);
+	ret = gedit_file_open_single_uri (uri);
 
-	if (ret)
-	{
-		gchar* t = gnome_vfs_x_format_uri_for_display (temp_uri);
-		gedit_utils_flash_va (_("Loaded file %s"), t);
-		g_free (t);
-	}
-
-	g_free (temp_uri);
-
-	gtk_widget_grab_focus (GTK_WIDGET (gedit_get_active_view ()));
+	active_view = gedit_get_active_view ();
+	if (active_view != NULL)
+		gtk_widget_grab_focus (GTK_WIDGET (active_view));
 
 	gedit_debug (DEBUG_FILE, "END");
 
@@ -620,7 +619,7 @@ gedit_file_open_single_uri (const gchar* uri)
 {
 	gchar *full_path;
 	gboolean ret = TRUE;
-	
+
 	gedit_debug (DEBUG_FILE, "");
 	
 	if (uri == NULL) return FALSE;
@@ -629,7 +628,12 @@ gedit_file_open_single_uri (const gchar* uri)
 
 	if (full_path != NULL) 
 	{
-		ret = gedit_file_open_real (full_path, NULL);
+		BonoboMDIChild *active_child = NULL;
+
+		active_child = bonobo_mdi_get_active_child (BONOBO_MDI (gedit_mdi));
+		
+		ret = gedit_file_open_real (full_path, 
+					    (active_child != NULL) ? GEDIT_MDI_CHILD (active_child): NULL);
 		if (ret)
 			gedit_utils_flash_va (_("Loaded file '%s'"), full_path);
 
@@ -652,7 +656,7 @@ gedit_file_open_from_stdin (GeditMDIChild *active_child)
 
 	gedit_debug (DEBUG_FILE, "");
 	
-	fstat(STDIN_FILENO, &stats);
+	fstat (STDIN_FILENO, &stats);
 	
 	if (stats.st_size  == 0)
 		return FALSE;
