@@ -56,6 +56,8 @@
 
 #include <gconf/gconf-client.h>
 
+#define RECENT_KEY "GeditRecent"
+
 struct _GeditMDIPrivate
 {
 	gint untitled_number;
@@ -221,6 +223,7 @@ gedit_mdi_app_created_handler (BonoboMDI *mdi, BonoboWindow *win)
 	GtkWidget *widget;
 	BonoboControl *control;
 	BonoboUIComponent *ui_component;
+	GeditRecent *recent;
 
 	static GtkTargetEntry drag_types[] =
 	{
@@ -312,6 +315,16 @@ gedit_mdi_app_created_handler (BonoboMDI *mdi, BonoboWindow *win)
 			(gpointer)win);
 
 
+	/* add a GeditRecent object */
+	/* FIXME: maybe max recent files should be a pref? */
+	recent = gedit_recent_new_with_ui_component ("gedit",
+						     4,
+						     ui_component,
+						     "/menu/File/Recents");
+	g_signal_connect (G_OBJECT (recent), "activate",
+			  G_CALLBACK (gedit_file_open_recent), NULL);
+	g_object_set_data (G_OBJECT (win), RECENT_KEY, recent);
+
 	/* Set the window prefs. */
 	gtk_window_set_default_size (GTK_WINDOW (win), 
 			gedit_settings->window_width, 
@@ -321,9 +334,6 @@ gedit_mdi_app_created_handler (BonoboMDI *mdi, BonoboWindow *win)
 	                  G_CALLBACK (gedit_prefs_configure_event_handler), 
 			  NULL);
 	
-	/* Add the recent files */
-	gedit_recent_init (win);
-
 	/* Add the plugins menus */
 	gedit_plugins_engine_update_plugins_ui (win, TRUE);
 }
@@ -605,18 +615,38 @@ gedit_mdi_set_app_statusbar_style (BonoboWindow *win)
 		goto error;
 
 	if (gedit_settings->statusbar_view_cursor_position)
-		gtk_widget_show (cp);
-	else
-		gtk_widget_hide (cp);
+	{
+		bonobo_ui_component_set_prop (
+			ui_component, "/status/CursorPosition", "hidden", "0", NULL);
 
+		gtk_widget_show (cp);
+	}
+	else
+	{
+		bonobo_ui_component_set_prop (
+			ui_component, "/status/CursorPosition", "hidden", "1", NULL);
+
+		gtk_widget_hide (cp);
+	}
+	
 	om = GTK_WIDGET (g_object_get_data (G_OBJECT (win), "OverwriteMode"));
 	if (om == NULL)
 		goto error;
 
 	if (gedit_settings->statusbar_view_overwrite_mode)
+	{
 		gtk_widget_show (om);
+		
+		bonobo_ui_component_set_prop (
+			ui_component, "/status/OverwriteMode", "hidden", "0", NULL);
+	}
 	else
+	{
+		bonobo_ui_component_set_prop (
+			ui_component, "/status/OverwriteMode", "hidden", "1", NULL);
+		
 		gtk_widget_hide (om);
+	}
 
 	if (!gedit_settings->statusbar_view_overwrite_mode)
 		gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (cp), TRUE);
@@ -626,10 +656,10 @@ gedit_mdi_set_app_statusbar_style (BonoboWindow *win)
 	if (!gedit_settings->statusbar_view_cursor_position &&
 	    !gedit_settings->statusbar_view_overwrite_mode)
 		bonobo_ui_component_set_prop (
-			ui_component, "/status/main", "resize_grip", "1", NULL);
+			ui_component, "/status", "resize_grip", "1", NULL);
 	else
 		bonobo_ui_component_set_prop (
-			ui_component, "/status/main", "resize_grip", "0", NULL);
+			ui_component, "/status", "resize_grip", "0", NULL);
 
 error:
 	bonobo_ui_component_thaw (ui_component, NULL);
@@ -1139,3 +1169,14 @@ gedit_mdi_update_ui_according_to_preferences (GeditMDI *mdi)
 	bonobo_mdi_set_mode (BONOBO_MDI (mdi), gedit_settings->mdi_mode);
 */
 }
+
+GeditRecent*
+gedit_mdi_get_recent_from_window (BonoboWindow* win)
+{
+	gpointer r;
+	gedit_debug (DEBUG_MDI, "");
+
+	r = g_object_get_data (G_OBJECT (win), RECENT_KEY);
+	
+	return (r != NULL) ? GEDIT_RECENT (r) : NULL;
+}
