@@ -27,6 +27,10 @@
  * See the ChangeLog files for a list of changes. 
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <libgnome/libgnome.h>
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomeprint/gnome-print-master.h>
@@ -716,6 +720,8 @@ gedit_print_line_number (GeditPrintJobInfo *pji, gdouble y)
 		
 	gint line_num = pji->first_line_to_print + pji->printed_lines;
 
+	gedit_debug (DEBUG_PRINT, "");
+
 	if ((pji->printed_lines + 1) % gedit_settings->print_line_numbers != 0)
 	       return;	
 		
