@@ -434,8 +434,9 @@ finally_2:
  * The following code is a modified version of the gtk one
  **********************************************************/
 
-	
+/*	
 gboolean      _gtk_text_btree_char_is_invisible (const GtkTextIter *iter);
+*/
 #define GTK_TEXT_UNKNOWN_CHAR 0xFFFC
 
 
@@ -462,7 +463,7 @@ forward_chars_with_skipping (GtkTextIter *iter,
 
       if (!ignored &&
           skip_invisible &&
-          _gtk_text_btree_char_is_invisible (iter))
+          /* _gtk_text_btree_char_is_invisible (iter)*/ FALSE)
         ignored = TRUE;
 
       gtk_text_iter_forward_char (iter);
@@ -898,7 +899,7 @@ gedit_utils_error_reporting_loading_file (
 		case GNOME_VFS_ERROR_TOO_MANY_OPEN_FILES:
 			error_message = g_strdup_printf (
 				_("Could not open the file \"%s\" because "
-				  "there are too many open files\n\n."
+				  "there are too many open files.\n\n"
 				  "Please, close some open file and try again."),
                          	uri_for_display);
                 	break;
